#
# spec file for package fping
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fping
Url:            http://www.fping.org
Version:        3.5
Release:        10.3.1
Summary:        A program to ping multiple hosts
License:        MIT
Group:          Productivity/Networking/Diagnostic
Source:         http://fping.org/dist/%{name}-%{version}.tar.gz
Patch0:         flooding-tmp-after-network-stop.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
FPing is a ping-like program that uses the Internet Control Message
Protocol (ICMP) echo request to determine if a target host is
responding. FPing differs from ping in that you can specify any number
of targets on the command line or specify a file containing a list of
targets to ping. Instead of sending pings to one target until it times
out or replies, FPing sends a ping packet and moves on to the next
target in a round-robin fashion.

In the default mode, if a target replies, it is noted and removed from
the list of targets to check. If a target does not respond within a
certain time limit or retry limit, it is designated as unreachable.
FPing also supports sending a specified number of pings to a target or
looping indefinitely (as in ping).

Unlike ping, FPing is meant to be used in scripts. Its output is
designed to be easy to parse.

%prep
%setup -q
%patch0 -p1

%build
export CFLAGS="%optflags -D_GNU_SOURCE -fwhole-program"
%configure --enable-ipv6 --enable-ipv4
make %{?_smp_mflags}

%install
%makeinstall

%files
%defattr(-,root,root)
%doc ChangeLog COPYING README
%{_mandir}/man8/fping*.8*
%{_sbindir}/fping
%{_sbindir}/fping6

%changelog
* Wed Sep 12 2018 Marketa Calabkova <mcalabkova@suse.com>
-  bsc#988195 - fping flooding /tmp after network stop
  * added patch flooding-tmp-after-network-stop.patch to fix it
* Sun Aug 18 2013 zaitor@opensuse.org
- Update to version 3.5:
  * Fix sprint_tm buffer size crash.
  * Addded -D flag to print timestamps.
  * Fix fping6 build on OS X 10.8.
  * Fix compatibility issue with FreeBSD (#39).
  * Fping.spec: fix setuid permissions and provides fping6.
  * Re-create configure script with autoconf 2.69 for aarch64
    support (#45).
* Thu Jan 31 2013 crrodriguez@opensuse.org
- Enable missing ipv6 support
- tweak out CFLAGS.
* Tue Oct 16 2012 puzel@suse.com
- update to 3.4
  * Revert "Output statistics to stdout instead of stderr", because
    it breaks tools assuming the output goes to stderr
* Mon Aug 20 2012 pascal.bleser@opensuse.org
- update to 3.3:
  * Do not output icmp errors with -q (#1)
  * Add --enable-ipv4 and --enable-ipv6 options to configure
  * Fix removing of unreachable hosts when doing loop (#13 #23)
  * Fix -A for fping6 (#14)
  * Fix "options inet6" breaking IPv4 name resolution (#17)
  * Output statistics to stdout instead of stderr (#9)
  * Set default data size to 56 bytes on all architectures (#18)
  * Convert man-page source to POD for easier maintenance
  * Fix error message on DNS error for IPv6 hosts (#27)
  * Fix -n flag in fping6 (#28)
* Fri Jun  8 2012 wojtek@suse.cz
-Update to 3.2
  * Improve documentation for -g option (G.W. Haywood)
  * Performance optimization for big select timeouts (#10, Andrey
  * Bondarenko)
  * Fix restart of select call after interrupt signal (#8, Boian
  * Bonev)
  * Fix infinite loop caused by linked list corruption (#11,
  * Boian Bonev)
* Sun May 20 2012 zaitor@opensuse.org
- Update to version 3.1:
  + -g option (generate): exclude network and broadcast address
    for cidr ranges.
  + do not explicitely check if running as root, to make it
    possible to install fping with linux capabilities instead of
    making it setuid (setcap cap_net_raw+ep fping).
  + ANSI C (C89) compiler now a requirement.
  + Portability fixes.
  + Reorganized source directory.
  + Bugfix: fix timeout issue on Solaris.
  + Man-page fixes.
  + Added -H option to specify number of hops.
  + Output usage information to stdout when called with -h
* Wed Feb  8 2012 puzel@suse.com
- update to fping-3.0
  * rewritten main loop for improved performance
  * -T parameter (select timeout) now obsolete
  * Maintenance taken over from unresponsive previous maintainer
  * New homepage: www.fping.org
- drop fping-2.4b2-fixwarnings.patch (obsolete)
* Sun Sep 18 2011 jengelh@medozas.de
- Apply packaging guidelines (remove redundant/obsolete
  tags/sections from specfile, etc.)
* Wed Nov 18 2009 puzel@novell.com
- add ipv6 support (bnc#555691)
* Fri Feb  8 2008 lrupp@suse.de
- convert the Changelog to Unix
- add COPYING, remove INSTALL from docudir
- use macros
- build parallel
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri May  7 2004 hmacht@suse.de
- Upgrade to version 2.4b2
* Thu Apr 22 2004 postadal@suse.cz
- fixed gcc warnings
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Mon Jun 11 2001 schwab@suse.de
- Fix alignment problem properly.
* Wed Jul 19 2000 schwab@suse.de
- Fix alignment problem.
- Pass CFLAGS during configure run.
* Thu Apr 13 2000 nadvornik@suse.cz
- added BuildRoot
* Sat Feb 12 2000 grimmer@suse.de
- added Group tag to spec file
- use version macro in spec file
- added full URL to Source tag
- use _mandir macro in spec file
- added CXXFLAGS to %%build section
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Thu Apr 22 1999 ro@suse.de
- fixed for alpha
* Fri Jan 29 1999 grimmer@suse.de
- new Package (Version 2.2b1)
